/* Copyright 2012 VMware, Inc. All rights reserved. -- VMware Confidential */
package com.vmware.samples.globalview {
import com.vmware.flexutil.proxies.BaseProxy;

/**
 * Proxy class for the GlobalService java service
 */
public class GlobalServiceProxy extends BaseProxy {
   // Service name matching the flex:remoting-destination declared in
   // main/webapp/WEB-INF/spring/bundle-context.xml
   private static const SERVICE_NAME:String = "GlobalService";

   // channelUri uses the Web-ContextPath define in MANIFEST.MF (chassis-ui)
   // A secure AMF channel is required because vSphere Web Client uses https
   private static const CHANNEL_URI:String =
         "/" + GlobalviewModule.contextPath + "/messagebroker/amfsecure";

   /**
    * Create a GlobalServiceProxy with a secure channel.
    */
   public function GlobalServiceProxy() {
      super(SERVICE_NAME, CHANNEL_URI);
   }

   /**
    * Call the "setSettings" method of GlobalService.
    *
    * @param settings      The new GlobalSettings value
    * @param callBack      Optional callback method
    * @param callContext   Optional object that is passed back in the callback method
    */
   public function setSettings(settings:GlobalSettings, callback:Function = null,
      context:Object = null):void {
      callService("setSettings", [settings], callback, context);
   }

   /**
    * Call the "getSettings" method of GlobalService.
    *
    * @param callBack      callback method used to return the result
    * @param callContext   Optional object that is passed back in the callback method
    */
   public function getSettings(callback:Function = null, context:Object = null):void {
      // This method takes no arguments
      callService("getSettings", [], callback, context);
   }
}
}